diff options
| author | zeertzjq <zeertzjq@outlook.com> | 2026-09-29 09:43:56 +0800 |
|---|---|---|
| committer | GitHub <noreply@github.com> | 2026-09-29 09:43:56 +0800 |
| commit | eddadd7ab33ece402ea43e9c0823f817404dc012 (patch) | |
| tree | 9e276669b162c9ead4878c8b6dfd0e5a969c2b49 /runtime/lua/vim/provider/python.lua | |
| parent | b77694f0ccb1d4e674faa6018adc70eac5fbeb34 (diff) | |
| download | rneovim-eddadd7ab33ece402ea43e9c0823f817404dc012.tar.gz rneovim-eddadd7ab33ece402ea43e9c0823f817404dc012.tar.bz2 rneovim-eddadd7ab33ece402ea43e9c0823f817404dc012.zip | |
vim-patch:9.2.1139: list2blob() can be improved (#42138)
Problem: list2blob() appends one byte at a time.
Solution: Preallocate the buffer and write the bytes directly
(Yasuhiro Matsumoto).
Cover large conversions, descending ranges, and invalid trailing items.
All 33 blob tests pass. Local five-run medians improve by 17% for 4096
items and 19% for 65536 items.
closes: vim/vim#21385
https://github.com/vim/vim/commit/c77608d35e899a0103d022fb9edb19c58ea00396
Co-authored-by: Yasuhiro Matsumoto <mattn.jp@gmail.com>
Diffstat (limited to 'runtime/lua/vim/provider/python.lua')
0 files changed, 0 insertions, 0 deletions